@@ -976,7 +976,7 @@ def is_eyesoff() -> bool:
     Returns a boolean of whether current workspace is eyes-off.
     """
     tenant_id = os.environ.get("AZ_BATCHAI_CLUSTER_TENANT_ID", "")
-    subscription_id = os.environ.get("AZ_BATCHAI_CLUSTER_SUBSCRIPTION_ID", "")
+    subscription_id = os.environ.get("AZUREML_ARM_SUBSCRIPTION", "")
     return is_eyesoff_helper(tenant_id, subscription_id)
 
 
